/**
 * Die Klasse Rectangle definiert Rechtecke und stellt Methoden
 * bereit um auf Rechteck-Objekten zu arbeiten
 * 
 * @author (Tobias Hennchen) 
 * @version (2007.05.22)
 */


public class Rectangle {

	//Koordinaten der linken unteren Ecke
	int x;
	int y;

	//Breite und Hhe des Rechtecks
	int width;
	int height;

	/**
	 * Konstruktor zur Initialisierung eines Rectangle-Objekts
	 *
	 * @param x Linker unterer Punkt (x-Wert)
	 * @param y Linker unterer Punkt (y-Wert)
	 * @param w Rechteck-Breite
	 * @param h Rechteck-Hhe
	 */
	Rectangle(int x, int y, int w, int h) {
		this.x = x;
		this.y = y;
		this.width = w;
		this.height = h;
	}

	/**
	 * Methode die die Breite eines Rechtecks zurueckgibt.
	 * 
	 * @return Breite des Rechtecks
	 */
	int getWidth() {
		return width;
	}

	/**
	 * Methode die die Hoehe eines Rechtecks zurueckgibt. 
	 *
	 * @return Hhe des Rechtecks
	 */
	int getHeight() {
		return height;
	}

	/**
	 * Methode die die linke Begrenzung eines Rechtecks zurueckgibt. 
	 * 
	 * @return linke Seite des Rechtecks (x-Wert)
	 */
	int getLeft() {
		return x;
	}

	/**
	 * Methode die die rechte Begrenzung eines Rechtecks zurueckgibt. 
	 * 
	 * @return rechte Seite des Rechtecks (x-Wert + Breite)
	 */
	int getRight() {
		return x + width;
	}

	/**
	 * Methode die die untere Begrenzung eines Rechtecks zurueckgibt. 
	 * 
	 * @return untere Seite des Rechtecks (y-Wert)
	 */
	int getBottom() {
		return y;
	}

	/**
	 * Methode die die obere Begrenzung eines Rechtecks zurueckgibt. 
	 * 
	 * @return obere Seite des Rechtecks (y-Wert + Hhe)
	 */
	int getTop() {
		return y + height;
	}

	/**
	 * Methode die prft ob Rechteck ein Quadrat. 
	 * 
	 * @return Wahr, falls Rechteck quadratisch ist.
	 */
	boolean isSquare() {
		//Ein Rechteck ist quadratisch, wenn
		//Breite und Hhe gleich sind.
		return width == height;
	}


	/**
	 * Methode die prft, ob ein Rechteck ein anderes einschliesst.
	 * 
	 * @param r Rechteck
	 * @return Wahr, wenn jeder Punkt dieses Rechtecks
	 * auch Punkt von r ist.
	 */
	boolean isContained(Rectangle r) {

		//Liegt aktuelles Rechteck (this)
		//innerhalb der Grenzen von r?
		return this.getLeft() >= r.getLeft()
			&& this.getBottom() <= r.getBottom()
			&& this.getTop() >= r.getTop()
			&& this.getRight() <= r. getRight();
	}

	/**
	 * Methode die prft, ob 2 Rechtecke nicht bereinander liegen.
	 * 
	 * @param r Rechteck
	 * @return wenn dieses Rechteck und r keinen gemeinsamen Punkt haben
	 */
	boolean isDisjoint(Rectangle r) {

		//aktuelles Rechteck muss jenseits einer
		//der Grenzen von r liegen
		return this.getLeft() >= r.getRight()
			|| this.getRight() <= r.getLeft()
			|| this.getTop() >= r.getBottom()
			|| this.getBottom() <= r.getTop();
	}


}
